==> terminusdb-react-components-0.0.1.tgz: package/es6/timetravel/helpers.test.js <==
"use strict";

var _helpers = require("./helpers");

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

test('difference between same date', function () {
  var now = Date.now();
  expect((0, _helpers.daydiff)(now, now)).toBe(0);
});
test('day difference between two days', function () {
  var first = new Date('01/01/1993');
  var second = new Date('01/02/1993');
  expect((0, _helpers.daydiff)(first, second)).toBe(86400000);
});
test('the zip', function () {
  var toZip = [['00', '01', '02'], ['10', '11', '12']];
  var result = [['00', '10'], ['01', '11'], ['02', '12']];
  expect((0, _helpers.zip)(toZip)).toEqual(result); // the initial one remains unchanged

  expect(toZip).toEqual(toZip);
});
test('forall arrays x and y and forall i in natural numbers zip([x, y][i] = [x[i], y[i]])', function () {
  for (var j = 0; j < 10; j += 1) {
    var len = Math.round(Math.random() * 100) + 1; // given any two arrays x and y

    var x = _toConsumableArray(Array(len).keys()).map(function (_) {
      return Math.random(_);
    });

    var y = _toConsumableArray(Array(len).keys()).map(function (_) {
      return Math.random(_);
    }); // the zip of those arrays z


    var z = (0, _helpers.zip)([x, y]); // has a property that the for all i : z[i] == [x[i], y[i]]

    for (var i = 0; i < len; i += 1) {
      expect(z[i]).toEqual([x[i], y[i]]);
    }
  }
});
test('dateDistanceExtremes', function () {
  var dates = [new Date('2016-01-01'), new Date('2016-01-02'), new Date('2016-01-05')];
  var singleDay = 86400000;
  var result = {
    min: singleDay,
    max: singleDay * 3
  };
  expect((0, _helpers.dateDistanceExtremes)(dates)).toEqual(result);
});

==> terminusdb-react-components-4.3.1.tgz: package/es6/timetravel/helpers.test.js <==
"use strict";

var _helpers = require("./helpers");

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

test('difference between same date', function () {
  var now = Date.now();
  expect((0, _helpers.daydiff)(now, now)).toBe(0);
});
test('day difference between two days', function () {
  var first = new Date('01/01/1993');
  var second = new Date('01/02/1993');
  expect((0, _helpers.daydiff)(first, second)).toBe(86400000);
});
test('the zip', function () {
  var toZip = [['00', '01', '02'], ['10', '11', '12']];
  var result = [['00', '10'], ['01', '11'], ['02', '12']];
  expect((0, _helpers.zip)(toZip)).toEqual(result); // the initial one remains unchanged

  expect(toZip).toEqual(toZip);
});
test('forall arrays x and y and forall i in natural numbers zip([x, y][i] = [x[i], y[i]])', function () {
  for (var j = 0; j < 10; j += 1) {
    var len = Math.round(Math.random() * 100) + 1; // given any two arrays x and y

    var x = _toConsumableArray(Array(len).keys()).map(function (_) {
      return Math.random(_);
    });

    var y = _toConsumableArray(Array(len).keys()).map(function (_) {
      return Math.random(_);
    }); // the zip of those arrays z


    var z = (0, _helpers.zip)([x, y]); // has a property that the for all i : z[i] == [x[i], y[i]]

    for (var i = 0; i < len; i += 1) {
      expect(z[i]).toEqual([x[i], y[i]]);
    }
  }
});
test('dateDistanceExtremes', function () {
  var dates = [new Date('2016-01-01'), new Date('2016-01-02'), new Date('2016-01-05')];
  var singleDay = 86400000;
  var result = {
    min: singleDay,
    max: singleDay * 3
  };
  expect((0, _helpers.dateDistanceExtremes)(dates)).toEqual(result);
});
